@@ -38,7 +38,11 @@ case_match. <- function(.x, ..., .default = NA, .ptype = NULL) {
 
 prep_case_match_dot <- function(dot, .x) {
   lhs <- f_lhs(dot)
-  lhs <- call2("%in%", .x, lhs, .ns = "tidytable")
+  if (is.character(lhs) || is.numeric(lhs)) {
+    lhs <- call2("==", .x, lhs)
+  } else {
+    lhs <- call2("%in%", .x, lhs, .ns = "tidytable")
+  }
   f_lhs(dot) <- lhs
   dot
 }
