@@ -21,29 +21,21 @@
 #'   mutate(row_mean = mean(c_across(x:z))) %>%
 #'   ungroup()
 rowwise <- function(.df) {
-  rowwise.(.df)
+  .df <- .df_as_tidytable(.df)
+
+  if (is_ungrouped(.df)) {
+    set_class(.df, c("rowwise_tt", tidytable_class()))
+  } else {
+    out <- ungroup(.df)
+    rowwise(out)
+  }
 }
 
 #' @export
 #' @keywords internal
 #' @inherit rowwise
 rowwise. <- function(.df) {
-  UseMethod("rowwise.")
-}
-
-#' @export
-rowwise..tidytable <- function(.df) {
-  set_class(.df, c("rowwise_tt", tidytable_class()))
-}
-
-#' @export
-rowwise..grouped_tt <- function(.df) {
-  out <- ungroup(.df)
-  rowwise(out)
-}
-
-#' @export
-rowwise..data.frame <- function(.df) {
-  .df <- as_tidytable(.df)
+  deprecate_dot_fun()
   rowwise(.df)
 }
+
