@@ -11,7 +11,8 @@ test_that("_head() works when empty", {
 test_that("_head.() works", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
   sliced_df <- test_df %>%
-    slice_head.()
+    slice_head.() %>%
+    suppressWarnings()
 
   expect_equal(sliced_df, head(test_df, 5))
 })
@@ -32,7 +33,7 @@ test_that("_head() works with n specified", {
   expect_equal(sliced_df, head(test_df, 3))
 })
 
-test_that("_head() works with n specified with by", {
+test_that("_head() works with n specified with .by", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
 
   col_order <- names(test_df)
@@ -43,6 +44,12 @@ test_that("_head() works with n specified with by", {
 
   expect_named(sliced_df, names(test_df))
   expect_equal(datatable_df, sliced_df)
+
+  sliced_df <- test_df %>%
+    slice_head(n = 3, by = z)
+
+  expect_named(sliced_df, names(test_df))
+  expect_equal(datatable_df, sliced_df)
 })
 
 test_that("_head() works in custom function", {
@@ -101,7 +108,8 @@ test_that("_tail() works when empty", {
 test_that("_tail.() works", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
   sliced_df <- test_df %>%
-    slice_tail.()
+    slice_tail.() %>%
+    suppressWarnings()
 
   expect_equal(sliced_df, tail(test_df, 5))
 })
@@ -122,7 +130,7 @@ test_that("_tail() works with n()", {
   expect_equal(sliced_df, test_df)
 })
 
-test_that("_tail() works with n specified with .by", {
+test_that("_tail() works with n specified with .by/by", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
 
   col_order <- names(test_df)
@@ -133,8 +141,14 @@ test_that("_tail() works with n specified with .by", {
 
   expect_named(sliced_df, names(test_df))
   expect_equal(datatable_df, sliced_df)
+
+  sliced_df <- test_df %>%
+    slice_tail(n = 3, by = z)
+
+  expect_equal(datatable_df, sliced_df)
 })
 
+
 test_that("_tail() works with a custom function", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
 
